(***********************************************************************)
(*                                                                     *)
(*                           Objective Caml                            *)
(*                                                                     *)
(*            Pierre Weis, projet Cristal, INRIA Rocquencourt          *)
(*                                                                     *)
(*  Copyright 2000 Institut National de Recherche en Informatique et   *)
(*  en Automatique.  Distributed only by permission.                   *)
(*                                                                     *)
(***********************************************************************)

(* [Ppm.draw filename x y] displays a PPM image stored in file
   [filename] in the graphic window, with lower left corner at [x, y].
   [Ppm.load filename] loads a PPM image stored in file [filename] as
   a matrix of colors. *)

(* Loading and saving images in portable format: PPM, PGM, and PBM.

PPM: portable pixmap (pixels (picture element) map).
PGM: portable greymap (grey scale map).
PBM: portable bitmap (binary digit map).

*)

val load : string -> Graphics.color array array;;
 (* [Ppm.load filename] reads the image contained in the file [filename],
    and returns an array of integers (representing the RGB colors of pixels).
    Assumes that the image is stored in PPM (Portable Pixmap) or PGM
    (Portable Greymap), or PBM (Portable Bitmap) formats.
    PPM format is 24 bits per pixel, and both ASCII and raw encoding
    are suppoorted.
    PGM format is 8 bits per pixel, and both ASCII and raw encoding
    are supported.
    PBM is 1 bit per pixel, and both ASCII and raw encoding
    are suppoorted.
    If a PPM image is followed by a PBM image in the same file, the
    PBM image is supposed to be the transparency mask of the first
    image : pixels set to [1] in the mask receive the [transp] color
    into the resulting image (see [save] below).
 *)

val save : string -> Graphics.color array array -> unit;;
 (* [Ppm.save] : filename img] stores image [img], on file [filename].
    Image is supposed to be represented as an array of colors in the
    spirit of images of the graphics library.
    The image is saved as a portable pixmap, in raw encoding mode.
    If the image contains transparent pixels (i.e. pixels with color
    [Graphics.transp]), an extra transparency mask is saved 
    in the file [filename], as a PBM image. (See [load] above.)
 *)

val save_bitmap : string -> Graphics.color array array -> unit;;
val load_bitmap : string -> Graphics.color array array;;
 (* Same as above for portable bitmaps. *)

val load_ppm : string -> Graphics.color array array;;
val save_ppm : string -> Graphics.color array array -> unit;;
 (* Equivalent to [load] and [save]. *)

val load_image : string -> Graphics.image;;
 (* [load_image filename] loads the PPM image in file [filename]. *)

val save_image : string -> Graphics.image -> unit;;
 (* [save_image filename img] saves [img] as a PPM image in file [filename]. *)
 
